@@ -1,6 +1,6 @@
 /* ws-datatypes.c
  *
- * Copyright (C) 2004 - 2006 Vivien Malerba
+ * Copyright (C) 2004 - 2007 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -18,12 +18,12 @@
  * USA
  */
 
+#include <libgnomedb-extra/libgnomedb-extra.h>
 #include "ws-datatypes.h"
 #include "workspace-page.h"
 #include <string.h>
 #include <glib-object.h>
 #include <gtk/gtk.h>
-#include <libgnomedb/libgnomedb.h>
 #include <glib/gi18n-lib.h>
 
 /* 
